@@ -9,14 +9,24 @@ import os
 # this can be removed.
 os.environ["PROTOCOL_BUFFERS_PYTHON_IMPLEMENTATION"] = "python"
 
-logger = logging.getLogger("deepdriver")
+try:
+  from google.protobuf.internal import builder as _builder
+except ImportError:
+  # tensorflow와 protobuf 버젼 호환 문제로 protovuf 4.2.x 버젼을 사용하게 함
+  raise ImportError("A higher protobuf package version is requried. Upgrade protobuf using 'pip install --upgrade protobuf==4.21.12'" )
 
-console_handler = logging.StreamHandler(sys.stdout)
-if not util.is_notebook():
+logger = logging.getLogger("deepdriver")
+logger.propagate = False
+if logger.handlers == []:
+  console_handler = logging.StreamHandler(sys.stdout)
+  if not util.is_notebook():
     formatter = logging.Formatter('%(asctime)s %(levelname)s [%(name)s] [%(filename)s:%(lineno)d] - %(message)s')
     console_handler.setFormatter(formatter)
-logger.setLevel(logging.INFO)
-logger.addHandler(console_handler)
+  else:
+    formatter = logging.Formatter('%(message)s')
+    console_handler.setFormatter(formatter)
+  logger.setLevel(logging.INFO)
+  logger.addHandler(console_handler)
 
 
 from deepdriver.sdk.artifact import *
@@ -35,7 +45,9 @@ from deepdriver.sdk.data_types.dataFrame import DataFrame
 from deepdriver.sdk.data_types.image import Image
 from deepdriver.sdk.data_types.table import Table
 
-from deepdriver.intergration.keras import keras
+
+from deepdriver.sdk.lib.lazyloader import LazyLoader
+keras = LazyLoader('deepdriver.intergration.keras', globals(), 'deepdriver.intergration.keras.keras')  #layzyload
+
 config = Config()
 
-
