@@ -349,6 +349,9 @@ def init(exp_name: str = "", team_name: str = "", run_name: str = "", config: Di
 def create_hpo(exp_name: str = "", team_name: str = "", hpo_config: Dict = None) -> Dict:
     return http_interface.create_hpo(get_http_host(), exp_name, team_name, hpo_config)
 
+def get_hpo(exp_name: str = "", team_name: str = "") -> Dict:
+    return http_interface.get_hpo(get_http_host(), exp_name, team_name)
+
 def finish(data: Dict) -> Dict:
     return http_interface.finish(get_http_host(), data)
 
